@@ -1,8 +1,9 @@
 har <- function(x0, constr, N, thin=1, homogeneous=FALSE, transform=NULL) {
   n <- length(x0)
-  m <- dim(constr$constr)[1]
+  m <- nrow(constr$constr)
 
   # Verify preconditions that the C-code cannot check
+  stopifnot(n > homogeneous)
   stopifnot(n == dim(constr$constr)[2])
   stopifnot(m == length(constr$rhs))
   stopifnot(constr$dir == "<=")
@@ -13,7 +14,7 @@ har <- function(x0, constr, N, thin=1, homogeneous=FALSE, transform=NULL) {
     x0 <- c(x0, 1.0)
   }
 
-  samples <- .C("har",
+  samples <- .C("hitandrun_har",
     as.integer(n - 1), as.double(x0),
     as.integer(m), as.double(constr$constr), as.double(constr$rhs),
     as.integer(N), as.integer(thin),
@@ -33,10 +34,11 @@ har <- function(x0, constr, N, thin=1, homogeneous=FALSE, transform=NULL) {
 }
 
 bbReject <- function(lb, ub, constr, N, homogeneous=FALSE, transform=NULL) {
-  n <- dim(constr$constr)[2]
-  m <- dim(constr$constr)[1]
+  n <- ncol(constr$constr)
+  m <- nrow(constr$constr)
 
   # Verify preconditions that the C-code cannot check
+  stopifnot(n > homogeneous)
   if (homogeneous == FALSE) {
     stopifnot(n == length(lb))
     stopifnot(n == length(ub))
@@ -52,7 +54,7 @@ bbReject <- function(lb, ub, constr, N, homogeneous=FALSE, transform=NULL) {
     constr$constr <- cbind(constr$constr, 0)
   }
 
-  result <- .C("bbReject",
+  result <- .C("hitandrun_bbReject",
     as.integer(n - 1), as.double(lb), as.double(ub),
     as.integer(m), as.double(constr$constr), as.double(constr$rhs),
     as.integer(N),
@@ -72,10 +74,21 @@ bbReject <- function(lb, ub, constr, N, homogeneous=FALSE, transform=NULL) {
 }
 
 simplex.sample <- function(n, N, sort=FALSE) {
-  samples <- .C("simplexSample",
+  samples <- .C("hitandrun_simplexSample",
     as.integer(n), as.integer(sort), as.integer(N),
     samples=matrix(0.0, nrow=N, ncol=n),
     NAOK=FALSE, DUP=FALSE, PACKAGE="hitandrun"
   )$samples
   list(samples=samples)
 }
+
+hypersphere.sample <- function(n, N) { 
+  sample <- .C("hitandrun_hypersphereSample",
+               as.integer(n),
+               as.integer(N),
+               sample=matrix(0.0, nrow=N, ncol=n),
+               NAOK=FALSE, DUP=FALSE, PACKAGE="hitandrun"
+               )$sample
+  
+  return(sample)
+}
